# Constants
A couple of constant values.
Even though those are constant values, you can change them, but you usually don't need to.

## `WS_URL: str`
Contains the websocket URL.
Default value: `"wss://msgroom.windows96.net/socket.io"`